#include <iostream>
#include <complex>
#include <cmath>
#include <cassert>
#include <vector>

#define EPS 1e-8

using namespace std;

typedef complex<double> point;
// you should look up the complex type in c++, it's very helpful for geometry!
// here, both the real and imaginary part are have the "double" type,
// can also use integer types if needed

// the sequence of points defining the polygon
vector<point> poly;

double cross(point p, point q) {
    // same as real(p)*imag(q) - imag(q)*real(p)
    // here conj(q) is the complex conjugate of q (i.e. the imaginary part is negated)
    return imag(p*conj(q));
}

double dot(point p, point q) {
    // same as real(p)*real(q) + imag(p)*imag(q)
    return real(p*conj(q));
}

const char* solve(point p) {
    double theta = 0; // total change in angle as we walk around the polygon

    for (int i = 0, j = poly.size()-1; i < poly.size(); j = i++) {
        point q = poly[i]-p, r = poly[j]-p;

        if (fabs(cross(q, r)) < EPS && dot(q, r) <= EPS) return "on";

        // Get the angle between q and r, measured between -pi and pi.
        // This is a very helful trick! The angle of the complex point q/r
        // from the real-axis is the same as the angle between q and r.
        theta += arg(q / r);
    }

    return fabs(theta) < EPS ? "out" : "in";
}

int main() {
    int n;
    while ((cin >> n) && n) {
        double x, y;

        poly.clear();
        while (n--) {
            cin >> x >> y;
            poly.push_back(point(x, y));
        }

        int m;
        cin >> m;
        while (m--) {
            cin >> x >> y;
            cout << solve(point(x, y)) << endl;
        }
    }
    return 0;
}
